# -*- coding: utf-8 -*-

import os
import json

from ydl_ai_recommender.src.utils.log import create_logger
from ydl_ai_recommender.src.core.manager import Manager
# from ydl_ai_recommender.src.core.manager import OrderDataManager, ChatDataManager


class UserCounselorIndexManager(Manager):

    def __init__(self) -> None:
        super().__init__(create_logger(__name__, 'order_data_manager.log'))
        # self.order_data_manager = OrderDataManager()
        # self.chat_data_manager = ChatDataManager()


    def make_index(self):
        self.logger.info('开始构建用户-咨询师 合并索引')

        with open(os.path.join(self.local_file_dir, 'user_doctor_index.json'), encoding='utf-8') as f:
            user_doctor_index = json.load(f)

        with open(os.path.join(self.local_file_dir, 'user_doctor_chat_index.json'), encoding='utf-8') as f:
            user_doctor_chat_index = json.load(f)

        merged_index = {}

        for uid, counselors in user_doctor_index.items():
            chat_index = {
                c_id: value for c_id, value in user_doctor_chat_index.get(uid, [])
            }
            new_counselors = []
            for [c_id, value] in counselors:
                if c_id in chat_index:
                    merge_value = value * 0.6 + chat_index[c_id] * 0.4
                else:
                    merge_value = value * 0.6
                new_counselors.append([c_id, merge_value])

            merged_index[uid] = sorted(new_counselors, key=lambda x: x[1], reverse=True)

        self.logger.info('用户-咨询师 合并索引构建完成，共构建 %s 条数据', len(merged_index))
        with open(os.path.join(self.local_file_dir, 'merged_user_doctor_index.json'), 'w', encoding='utf-8') as f:
            json.dump(merged_index, f, ensure_ascii=False)

            

if __name__ == '__main__':
    manager = UserCounselorIndexManager()
    manager.make_index()